@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2019 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -267,20 +267,8 @@ public interface Constants extends Messages {
 
     String NodeWasLeft(String nodeName);
 
-    String Process_SLA_Compliance();
-    
-    String SlaNA();
-    
-    String SlaPending();
-    
-    String SlaMet();
-    
-    String SlaAborted();
-    
-    String SlaViolated();
-    
     String SlaCompliance();
-    
+
     String SlaDueDate();
 
     String Process_Diagram_Not_FoundContainerShouldBeAvailable(String container);
@@ -354,4 +342,12 @@ public interface Constants extends Messages {
     String TimerInstanceRescheduled(String timerId);
 
     String Trigger();
+
+    String TimerDelayHelp();
+
+    String DeploymentId();
+
+    String Default_Process_Definition_Name();
+
+    String FilterAll();
 }
